django_analyses.serializers.output package — django_analyses 0.0.3 documentation

# django_analyses.serializers.output package

## Subpackages

- django_analyses.serializers.output.definitions package
  - Submodules
  - django_analyses.serializers.output.definitions.file_output_definition module
  - django_analyses.serializers.output.definitions.output_definition module
  - Module contents
- django_analyses.serializers.output.types package
  - Submodules
  - django_analyses.serializers.output.types.file_output module
  - Module contents

## Submodules

## django_analyses.serializers.output.output module

class `django_analyses.serializers.output.output.` `OutputSerializer`(instance=None, data=<class 'rest_framework.fields.empty'>, **kwargs)

  Bases: `django_analyses.serializers.utils.polymorphic.PolymorphicSerializer`

  class `Meta`

    Bases: `object`

    `fields` = '__all__'
    `model`

      alias of `django_analyses.models.output.output.Output`

  `get_serializer`(output_type: str) → rest_framework.serializers.Serializer

    Return a dict to map class names to their respective serializer classes. To be implemented by all PolymorphicSerializer subclasses.

`django_analyses.serializers.output.output.` `get_extra_output_serializers`() → dict

## django_analyses.serializers.output.output_specification module

class `django_analyses.serializers.output.output_specification.` `OutputSpecificationSerializer`(instance=None, data=<class 'rest_framework.fields.empty'>, **kwargs)

  Bases: `rest_framework.serializers.HyperlinkedModelSerializer`

  class `Meta`

    Bases: `object`

    `fields` = ('id', 'analysis', 'output_definitions', 'created', 'modified', 'url')
    `model`

      alias of `django_analyses.models.output.output_specification.OutputSpecification`

## Module contents